name: "test"

stages {
  name: "src"
  type: SOURCE_IMAGE
  source_param {
    path: "images/test.png"
  }
}

stages {
	name: "src_resize"
	type: RESIZE
	input: "src"
	resize_param {
		fx: 0.5
		fy: 0.5
	}
}

stages {
	name: "fg_areas"
	type: SVM_SEGMENTATION
	input: "src_resize"
	svm_segmentation_param {
		model_file: "models/svm/model.npz"
		scale: 0.003921568627
	}
}

stages {
	name: "fill"
	type: FILL_HOLES
	input: "fg_areas"
	fill_holes_param {
		val: 255
	}
}

stages {
	name: "morph"
	type: MORPHOLOGY
	input: "fill"
	morphology_param {
		type: OPEN
		iterations_num: 1
		kernel {
			shape_str: "9x9"
			d:0   d:0   d:0   d:255 d:255 d:255 d:0   d:0   d:0
			d:0   d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:0
			d:0   d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:0
			d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255
			d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255
			d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:255
			d:0   d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:0
			d:0   d:255 d:255 d:255 d:255 d:255 d:255 d:255 d:0
			d:0   d:0   d:0   d:255 d:255 d:255 d:0   d:0   d:0
		}
	}
}

stages {
	name: "bitmask_resize"
	type: RESIZE
	input: "morph"
	resize_param {
		fx: 2
		fy: 2
	}
}

stages {
	name: "remove_areas"
	type: REMOVE_AREAS
	input: "bitmask_resize"
	remove_areas_param {
		threshold_min: 0
		threshold_max: 1000000
	}
}

stages {
	name: "item_shapes"
	type: SEGMENTATION
	input: "src"
	input: "remove_areas"
	segmentation_param {
		type: CONTOURS
		shape: POLYGON
		match_parents: true
		convex_hull: false
	}
}

stages {
	name: "item_cutout"
	input: "item_shapes"
	type: CUT_OUT
	cut_out_param {
		type: BOUNDING_BOX
		border_policy: KEEP
		margin_x: 32
		margin_y: 32
	}
}

stages {
	name: "segm_shape"
	input: "item_cutout"
	type: JOIN
}

stages {
  name: "flaw_all"
  type: NEURAL_NETWORK
  input: "item_cutout"
  neural_network_param {
    deploy: "models/cnn/deploy.prototxt"
    model: "models/cnn/net.caffemodel"
    scale: 0.003921568627
    fully_deploy: "models/cnn/deploy_fully.prototxt"
    fully_subst_layers: "fc4 => fc4-conv, fc5 => fc5-conv, fc6 => fc6-conv"
    fully_cluster: false
    heatmap: true

    gpu: false
  }
}

stages {
  name: "pad"
  type: PADDING
  input: "flaw_all"
  padding_param {
    size_left: 1
    size_right: 1
    size_top: 1
    size_bottom: 1
    color { d:0 d:0 d:0 }
    border_type: CONSTANT
  }
}

stages {
    name: "marg1"
    input: "pad"
    type: MARGINALIZATION
    marginalization_param {
        class_aggregation: "1,2,3,4,5,6,7,8,9"
    }
}

stages {
    name: "marg2"
    input: "marg1"
    type: MARGINALIZATION
    marginalization_param {
        merge_contiguous: true
        class_aggregation: "0; 1; 2:1,3:1,4:1,5:1,6:1,7:1,8:1,9:1"
    }
}

stages {
  name: "all_cont"
  type: CONTOURS_FINDER
  input: "marg2"
  contours_finder_param {
    threshold: 0.5
    value_type: RANKING
    num: 3
  }
}

stages {
  name: "stalk_flaw_filter"
  type: CLASS_FILTER
  input: "all_cont"
  class_filter_param {
    class_exclude: "0"
    default_policy: CLASS_ACCEPT
    value_threshold: 0.5
  }
}

